#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-ormolu-plugin
version:              2.3.0.0
visibility:           public
id:                   hls-ormolu-plugin-2.3.0.0-H02OLhnIkpLjobDfktYFo
key:                  hls-ormolu-plugin-2.3.0.0-H02OLhnIkpLjobDfktYFo
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
synopsis:             Integration with the Ormolu code formatter
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  7e2d13b0bee32c54b5260cd00554f572
exposed:              True
exposed-modules:      Ide.Plugin.Ormolu
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.3.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.3.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-ormolu-plugin-2.3.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-ormolu-plugin
hs-libraries:         HShls-ormolu-plugin-2.3.0.0-H02OLhnIkpLjobDfktYFo
depends:
    base-4.18.2.1 extra-1.7.16-KrpFpNhh5BQELeEbiAlFs2
    filepath-1.4.300.1 ghc-9.6.6 ghc-boot-th-9.6.6
    ghcide-2.3.0.0-FhAbwsYEp6gAQgAB6C5VjW
    hls-plugin-api-2.3.0.0-HoObs2qHfNKC106GqibI71
    lens-5.3.4-GdOistvs0Ub2JwuPi3uyv5
    lsp-2.2.0.0-KGqb1yHTwPvBLMtVxTPYxl mtl-2.3.1
    ormolu-0.7.0.0-4Dt0FVa7JbrHJHaI0IfhxT
    process-extras-0.7.4-ByKaXwOUyhnJyx65eGyQx3 text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-hls-ormolu-plugin/html/hls-ormolu-plugin.haddock

haddock-html:         /usr/share/doc/haskell-hls-ormolu-plugin/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

